==> wls-plugin-3.5.0-sources.jar: com/xebialabs/deployit/plugin/wls/step/DeleteArtifactStep.java <==
package com.xebialabs.deployit.plugin.wls.step;

import com.xebialabs.deployit.plugin.api.deployment.execution.DeploymentExecutionContext;
import com.xebialabs.deployit.plugin.api.deployment.execution.DeploymentStep;
import com.xebialabs.deployit.plugin.overthere.Host;
import com.xebialabs.overthere.OverthereConnection;
import com.xebialabs.overthere.OverthereFile;

@SuppressWarnings("serial")
public class DeleteArtifactStep implements DeploymentStep {

	private final int order;
	private final Host host;
	private final String artifactPath;

	public DeleteArtifactStep(int order, Host host, String artifactPath) {
		this.order = order;
		this.host = host;
		this.artifactPath = artifactPath;

	}

	@Override
	public String getDescription() {
		return String.format("Delete artifact %s", artifactPath);
	}

	@Override
	public Result execute(DeploymentExecutionContext ctx) throws Exception {
		OverthereConnection connection = host.getConnection();
		OverthereFile fileToDelete = connection.getFile(artifactPath);
		if (fileToDelete.exists()) {
			ctx.logOutput("Deleting " + artifactPath);
			fileToDelete.deleteRecursively();
			return Result.Success;
		} else {
			ctx.logOutput(String.format("Nothing exist at %s, skipping deletion", artifactPath));
			return Result.Success;
		}
	}

	@Override
	public int getOrder() {
		return order;
	}

	@Override
	public boolean equals(Object obj) {
		if (obj == this) {
			return true;
		}
		if (!(obj instanceof DeleteArtifactStep)) {
			return false;
		}
		DeleteArtifactStep other = (DeleteArtifactStep) obj;
		return host.equals(other.host) && artifactPath.equals(other.artifactPath);
	}

	@Override
	public int hashCode() {
		int result = 17;
		result = 31 * result + host.hashCode();
		result = 31 * result + artifactPath.hashCode();
		return result;
	}

}

==> wls-plugin-3.7.2-sources.jar: com/xebialabs/deployit/plugin/wls/step/DeleteArtifactStep.java <==
package com.xebialabs.deployit.plugin.wls.step;

import com.google.common.io.Closeables;
import com.xebialabs.deployit.plugin.api.deployment.execution.DeploymentExecutionContext;
import com.xebialabs.deployit.plugin.api.deployment.execution.DeploymentStep;
import com.xebialabs.deployit.plugin.overthere.Host;
import com.xebialabs.overthere.OverthereConnection;
import com.xebialabs.overthere.OverthereFile;

@SuppressWarnings("serial")
public class DeleteArtifactStep implements DeploymentStep {

	private final int order;
	private final Host host;
	private final String artifactPath;

	public DeleteArtifactStep(int order, Host host, String artifactPath) {
		this.order = order;
		this.host = host;
		this.artifactPath = artifactPath;

	}

	@Override
	public String getDescription() {
		return String.format("Delete artifact %s", artifactPath);
	}

	@Override
	public Result execute(DeploymentExecutionContext ctx) throws Exception {
		OverthereConnection connection = host.getConnection();
		OverthereFile fileToDelete = connection.getFile(artifactPath);
		if (fileToDelete.exists()) {
			ctx.logOutput("Deleting " + artifactPath);
			try {
				fileToDelete.delete();
			} finally {
				Closeables.closeQuietly(connection);
			}
			return Result.Success;
		} else {
			ctx.logOutput(String.format("Nothing exist at %s, skipping deletion", artifactPath));
			return Result.Success;
		}
	}

	@Override
	public int getOrder() {
		return order;
	}

	@Override
	public boolean equals(Object obj) {
		if (obj == this) {
			return true;
		}
		if (!(obj instanceof DeleteArtifactStep)) {
			return false;
		}
		DeleteArtifactStep other = (DeleteArtifactStep) obj;
		return host.equals(other.host) && artifactPath.equals(other.artifactPath);
	}

	@Override
	public int hashCode() {
		int result = 17;
		result = 31 * result + host.hashCode();
		result = 31 * result + artifactPath.hashCode();
		return result;
	}

}
